@@ -5,10 +5,10 @@
 
 library(geneticae)
 # Data without replication
+library(agridat)
 data(yan.winterwheat)
-dat <- yan.winterwheat
 
-dat2 <- dat
+dat2 <- yan.winterwheat
 dat2[1,3]<-NA
 dat2[3,3]<-NA
 dat2[2,3]<-NA
@@ -16,7 +16,7 @@ dat2[2,3]<-NA
 
 test_that("Several tests for impute function", {
 
-  expect_error(imputation(dat, genotype="gen",environment="env", response="yield", type="EM-SVD"),
+  expect_error(imputation(yan.winterwheat, genotype="gen",environment="env", response="yield", type="EM-SVD"),
                "There are not missing data in input data frame")
 
   expect_error(imputation( genotype="gen",environment="env", response="yield", type="EM-SVD"),
